# Brisk

[![PyPI version](https://badge.fury.io/py/brisk-ml.svg)](https://badge.fury.io/py/brisk-ml)
[![Python 3.10+](https://img.shields.io/badge/python-3.10+-blue.svg)](https://www.python.org/downloads/)
[![Coverage Status](https://coveralls.io/repos/github/BFieguth/brisk/badge.svg?branch=main)](https://coveralls.io/github/BFieguth/brisk?branch=main)
![Documentation Status](https://readthedocs.org/projects/brisk/badge/?version=latest)

Brisk is a framework that helps train machine learning models using scikit-learn. 
Brisk provides a structured approach to organizing machine learning code and provides built in methods for common model evaluation and visualization tasks. Your results
are formatted as an HTML report to make evaluation and comparison easy.

## Why Use Brisk?
- **Organized Project Structure**: Avoid messy notebooks and scripts with a clean, modular approach to ML projects
- **Streamlined Experimentation**: Easily try different algorithms, hyperparameters, and data processing methods
- **Easy Evaluation**: Built-in methods for model evaluation and visualization
- **HTML Reports**: Automatically generate comprehensive reports of your model performance

## New to Brisk?
The [documentation](https://brisk.readthedocs.io/en/latest/) is the best place to 
start.The [Quick Start Guide](https://brisk.readthedocs.io/en/latest/getting_started/quickstart/index.html) will walk you through a simple project to learn the basics.


## Installation

Brisk is available on PyPI and can be installed using pip:

```bash
pip install brisk-ml
```

See the [installation](https://brisk.readthedocs.io/en/latest/getting_started/quickstart/install.html) page for more information.


## Contributing

See the [contributing](https://brisk.readthedocs.io/en/latest/dev/contribute.html) page for more information.
